# AnalysisJob

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | 
**analysis_id** | **str** |  | 
**analysis** | [**Analysis**](Analysis.md) |  | [optional] 
**type** | **str** |  | 
**project_id** | **str** |  | 
**project** | [**Project**](Project.md) |  | [optional] 
**execution_id** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**statuses** | [**list[AnalysisJobStatus]**](AnalysisJobStatus.md) |  | [optional] 
**outputs** | [**list[AnalysisJobOutput]**](AnalysisJobOutput.md) |  | [optional] 
**model_batch_jobs** | [**list[ModelBatchJob]**](ModelBatchJob.md) |  | [optional] 
**process_jobs** | [**list[ProcessJob]**](ProcessJob.md) |  | [optional] 
**feature_sub_categories** | [**list[FeatureSubCategory]**](FeatureSubCategory.md) |  | 
**config** | [**AnalysisJobConfig**](AnalysisJobConfig.md) |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**started_at** | **datetime** |  | [optional] 
**ended_at** | **datetime** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

